@@ -1,8 +1,8 @@
 ## ---- echo = FALSE-------------------------------------------------------
 
-is_latex <- knitr::opts_knit$get('rmarkdown.pandoc.to') == 'latex'
-
 library(huxtable)
+is_latex <- guess_knitr_output_format() == 'latex'
+
 comp <- read.csv('comparison.csv', stringsAsFactors = FALSE, header = FALSE)
 
 ch <- as_hux(comp)
@@ -16,7 +16,7 @@ background_color(ch)[, seq(3, ncol(ch), 2)] <- grey(.95)
 rotation(ch)[1,] <- 270
 valign(ch)[1,] <- 'middle'
 align(ch)[-1, -1] <- 'center'
-ch <- set_all_padding(ch, -1, , 0)
+ch <- set_all_padding(ch, -1, everywhere, 0)
 
 ch <- rbind(ch, rep('', ncol(ch)))
 last <- nrow(ch)
@@ -28,7 +28,7 @@ colspan(ch)[last, 1]   <- ncol(ch)
 bold(ch)[last, 1]      <- FALSE
 italic(ch)[last, 1]    <- FALSE
 bottom_border(ch)[last, 1] <- 2
-
+wrap(ch) <- TRUE
 
 if (is_latex) {
   row_height(ch) <- c('20pt', rep('10pt', nrow(ch) - 1))
