@@ -68,3 +68,18 @@ test_that('huxreg number_format works correctly', {
   expect_equal(number_format(hr2)[9,2], list('%5.3f'))
   expect_match(to_screen(hr2), paste0('\\D', sprintf('%5.3f', coef(lm1)[2]),'\\D'))
 })
+
+test_that('huxreg stars printed correctly', {
+  set.seed(27101975)
+  dfr <- data.frame(y = rnorm(20), a = rnorm(20))
+  dfr$y <- dfr$y + dfr$a + rnorm(20, 0, 4)
+  dfr$z <- dfr$a + rnorm(20, 0, 1)
+  lm1 <- lm(y ~ a, dfr)
+  lm2 <- lm(z ~ a, dfr)
+  number_regex <- '\\s*(\\d|\\.)+\\s*'
+  expect_match(huxreg(lm1)[[4, 2]], number_regex)
+  expect_match(huxreg(lm1, stars = c('@' = 0.1))[[4, 2]], paste0(number_regex, '@\\s*'))
+  expect_match(huxreg(lm1, stars = c('@' = 0.1, 'wrong' = 0.05))[[4, 2]], paste0(number_regex, '@\\s*'))
+  expect_match(huxreg(lm1, stars = c('wrong' = 0.05, '@' = 0.1))[[4, 2]], paste0(number_regex, '@\\s*'))
+  expect_match(huxreg(lm2)[[4, 2]], paste0(number_regex, '\\*\\*\\*\\s*'))
+})
